"use client";
import { useEffect, useState } from "react";
import { databases, ID, Query, account, DATABASE_ID, COLLECTION_ID } from "@/lib/appwrite";

const CrudPage = () => {
    const [title, setTitle] = useState("");
    const [description, setDescription] = useState("");
    const [documents, setDocuments] = useState([]);
    const [userRole, setUserRole] = useState("reader"); // Default role
    const [errorMessage, setErrorMessage] = useState("");

    useEffect(() => {
        account.get()
            .then(session => {
                fetchUserRole();
            })
            .catch(err => console.error("Session Error:", err));
        fetchDocuments();
    }, []);

    const fetchUserRole = async () => {
        try {
            const session = await account.get();
            if (!session || !session.$id) return;
            const userDoc = await databases.listDocuments(DATABASE_ID, COLLECTION_ID, [Query.equal("userId", session.$id)]);
            setUserRole(userDoc.documents.length > 0 ? userDoc.documents[0].role : "reader");
        } catch (error) {
            console.error("Error fetching user role:", error);
        }
    };

    const fetchDocuments = async () => {
        try {
            const response = await databases.listDocuments(DATABASE_ID, COLLECTION_ID);
            setDocuments(response.documents);
        } catch (error) {
            console.error("Error fetching documents:", error.message);
        }
    };

    const createDocument = async () => {
        if (!title || !description) return alert("Title and Description required!");
        try {
            const session = await account.get();
            if (!session || !session.$id) return;
            const response = await databases.createDocument(DATABASE_ID, COLLECTION_ID, ID.unique(), { title, description, userId: session.$id, role: userRole || "reader" });
            setDocuments([...documents, response]);
            setTitle("");
            setDescription("");
        } catch (error) {
            console.error("Error creating document:", error.message);
        }
        await fetchUserRole();
    };

    const updateDocument = async (docId) => {
        const newTitle = prompt("Enter new title:");
        if (!newTitle) return;
        try {
            await databases.updateDocument(DATABASE_ID, COLLECTION_ID, docId, { title: newTitle });
            fetchDocuments();
        } catch (error) {
            console.error("Error updating document:", error.message);
        }
    };

    const deleteDocument = async (docId) => {
        try {
            await databases.deleteDocument(DATABASE_ID, COLLECTION_ID, docId);
            setDocuments(documents.filter((doc) => doc.$id !== docId));
            setErrorMessage("");
        } catch (error) {
            setErrorMessage("You are not authorized to delete this document.");
        }
    };

    return (
        <div className="p-8 max-w-3xl mx-auto">
            <h1 className="text-3xl font-bold mb-6 text-center text-gray-800">CRUD Operations with Appwrite</h1>
            {userRole !== "reader" && (
                <div className="bg-white p-6 shadow-md rounded-lg mb-6">
                    <input type="text" placeholder="Enter title" value={title} onChange={(e) => setTitle(e.target.value)} className="border p-3 rounded w-full mb-3" />
                    <input type="text" placeholder="Enter description" value={description} onChange={(e) => setDescription(e.target.value)} className="border p-3 rounded w-full mb-3" />
                    <button onClick={createDocument} disabled={userRole === "reader"} className="w-full bg-blue-600 hover:bg-blue-700 text-white py-2 rounded-md transition">Create Document</button>
                </div>
            )}

            <div className="space-y-4">
                {documents.map((doc) => (
                    <div key={doc.$id} className="bg-white p-6 shadow-md rounded-lg">
                        <h3 className="text-xl font-semibold text-gray-700">{doc.title}</h3>
                        <p className="text-gray-600">{doc.description || "No description available"}</p>
                        {userRole !== "reader" && (
                            <div className="mt-4 flex space-x-2">
                                <button onClick={() => updateDocument(doc.$id)} className="bg-yellow-500 hover:bg-yellow-600 text-white px-4 py-2 rounded transition">Edit</button>
                                <button onClick={() => deleteDocument(doc.$id)} className="bg-red-500 hover:bg-red-600 text-white px-4 py-2 rounded transition">Delete</button>
                            </div>
                        )}
                    </div>
                ))}
            </div>

            {errorMessage && <p className="text-red-500 text-center mt-4">{errorMessage}</p>}
        </div>
    );
};

export default CrudPage;
